/*
   File: constant.h
   Does constant propagation across all rules and meta rules
   This pass is necessary for implementing the finite lattices
  
   CVS ID: "$Id: constant.h,v 1.3 2004/12/26 00:48:44 marcs Exp $"
*/
#ifndef IncConstant
#define IncConstant

void propagate_constants ();

#endif /* IncConstants */
